@@ -59,11 +59,16 @@ class settingsWindow(QWidget, Ui_Settings):
         self.lstMenu.setMaximumWidth(140)
         self.lstMenu.setMinimumWidth(140)
 
+        lowerKeys = [i.lower() for i in list(QStyleFactory.keys())]
+
         # General
         self.cmbStyle.addItems(list(QStyleFactory.keys()))
-        self.cmbStyle.setCurrentIndex(
-            [i.lower() for i in list(QStyleFactory.keys())]
-            .index(qApp.style().objectName()))
+
+        try:
+            self.cmbStyle.setCurrentIndex(lowerKeys.index(qApp.style().objectName()))
+        except ValueError:
+            self.cmbStyle.setCurrentIndex(0)
+
         self.cmbStyle.currentIndexChanged[str].connect(self.setStyle)
 
         self.cmbTranslation.clear()
@@ -111,6 +116,9 @@ class settingsWindow(QWidget, Ui_Settings):
         self.spnGeneralFontSize.setValue(f.pointSize())
         self.spnGeneralFontSize.valueChanged.connect(self.setAppFontSize)
 
+        self.chkProgressChars.setChecked(settings.progressChars);
+        self.chkProgressChars.stateChanged.connect(self.charSettingsChanged)
+
         self.txtAutoSave.setValidator(QIntValidator(0, 999, self))
         self.txtAutoSaveNoChanges.setValidator(QIntValidator(0, 999, self))
         self.chkAutoSave.setChecked(settings.autoSave)
@@ -135,15 +143,15 @@ class settingsWindow(QWidget, Ui_Settings):
         self.chkRevisionsKeep.stateChanged.connect(self.revisionsSettingsChanged)
         self.chkRevisionRemove.setChecked(opt["smartremove"])
         self.chkRevisionRemove.toggled.connect(self.revisionsSettingsChanged)
-        self.spnRevisions10Mn.setValue(60 / opt["rules"][10 * 60])
+        self.spnRevisions10Mn.setValue(int(60 / opt["rules"][10 * 60]))
         self.spnRevisions10Mn.valueChanged.connect(self.revisionsSettingsChanged)
-        self.spnRevisionsHour.setValue(60 * 10 / opt["rules"][60 * 60])
+        self.spnRevisionsHour.setValue(int(60 * 10 / opt["rules"][60 * 60]))
         self.spnRevisionsHour.valueChanged.connect(self.revisionsSettingsChanged)
-        self.spnRevisionsDay.setValue(60 * 60 / opt["rules"][60 * 60 * 24])
+        self.spnRevisionsDay.setValue(int(60 * 60 / opt["rules"][60 * 60 * 24]))
         self.spnRevisionsDay.valueChanged.connect(self.revisionsSettingsChanged)
-        self.spnRevisionsMonth.setValue(60 * 60 * 24 / opt["rules"][60 * 60 * 24 * 30])
+        self.spnRevisionsMonth.setValue(int(60 * 60 * 24 / opt["rules"][60 * 60 * 24 * 30]))
         self.spnRevisionsMonth.valueChanged.connect(self.revisionsSettingsChanged)
-        self.spnRevisionsEternity.setValue(60 * 60 * 24 * 7 / opt["rules"][None])
+        self.spnRevisionsEternity.setValue(int(60 * 60 * 24 * 7 / opt["rules"][None]))
         self.spnRevisionsEternity.valueChanged.connect(self.revisionsSettingsChanged)
 
         # Views
@@ -164,10 +172,12 @@ class settingsWindow(QWidget, Ui_Settings):
         for item, what, value in [
             (self.rdoTreeItemCount, "InfoFolder", "Count"),
             (self.rdoTreeWC, "InfoFolder", "WC"),
+            (self.rdoTreeCC, "InfoFolder", "CC"),
             (self.rdoTreeProgress, "InfoFolder", "Progress"),
             (self.rdoTreeSummary, "InfoFolder", "Summary"),
             (self.rdoTreeNothing, "InfoFolder", "Nothing"),
             (self.rdoTreeTextWC, "InfoText", "WC"),
+            (self.rdoTreeTextCC, "InfoText", "CC"),
             (self.rdoTreeTextProgress, "InfoText", "Progress"),
             (self.rdoTreeTextSummary, "InfoText", "Summary"),
             (self.rdoTreeTextNothing, "InfoText", "Nothing"),
@@ -180,6 +190,9 @@ class settingsWindow(QWidget, Ui_Settings):
             lambda v: self.lblTreeIconSize.setText("{}x{}".format(v, v)))
         self.sldTreeIconSize.setValue(settings.viewSettings["Tree"]["iconSize"])
 
+        self.chkCountSpaces.setChecked(settings.countSpaces);
+        self.chkCountSpaces.stateChanged.connect(self.countSpacesChanged)
+
         self.rdoCorkOldStyle.setChecked(settings.corkStyle == "old")
         self.rdoCorkNewStyle.setChecked(settings.corkStyle == "new")
         self.rdoCorkNewStyle.toggled.connect(self.setCorkStyle)
@@ -338,6 +351,11 @@ class settingsWindow(QWidget, Ui_Settings):
         sttgs = QSettings(qApp.organizationName(), qApp.applicationName())
         sttgs.setValue("appFontSize", val)
 
+    def charSettingsChanged(self):
+        settings.progressChars = True if self.chkProgressChars.checkState() else False
+
+        self.mw.mainEditor.updateStats()
+
     def saveSettingsChanged(self):
         if self.txtAutoSave.text() in ["", "0"]:
             self.txtAutoSave.setText("1")
@@ -427,10 +445,12 @@ class settingsWindow(QWidget, Ui_Settings):
         for item, what, value in [
             (self.rdoTreeItemCount, "InfoFolder", "Count"),
             (self.rdoTreeWC, "InfoFolder", "WC"),
+            (self.rdoTreeCC, "InfoFolder", "CC"),
             (self.rdoTreeProgress, "InfoFolder", "Progress"),
             (self.rdoTreeSummary, "InfoFolder", "Summary"),
             (self.rdoTreeNothing, "InfoFolder", "Nothing"),
             (self.rdoTreeTextWC, "InfoText", "WC"),
+            (self.rdoTreeTextCC, "InfoText", "CC"),
             (self.rdoTreeTextProgress, "InfoText", "Progress"),
             (self.rdoTreeTextSummary, "InfoText", "Summary"),
             (self.rdoTreeTextNothing, "InfoText", "Nothing"),
@@ -445,6 +465,11 @@ class settingsWindow(QWidget, Ui_Settings):
 
         self.mw.treeRedacOutline.viewport().update()
 
+    def countSpacesChanged(self):
+        settings.countSpaces = True if self.chkCountSpaces.checkState() else False
+
+        self.mw.mainEditor.updateStats()
+
     def setCorkColor(self):
         color = QColor(settings.corkBackground["color"])
         self.colorDialog = QColorDialog(color, self)
